from clight.system.importer import cli  # DON'T REMOVE THIS LINE
from clight.system.importer import SemVer  # DON'T REMOVE THIS LINE

# <umbrella-package>
# import testufirst==1:0:2
# import testusecond==1:0:1
# import testuthird==1:0:1
# </umbrella-package>

import os
import sys
import subprocess
import testufirst
import importlib.metadata

from modules.jobs import jobs



from setuptools import setup, find_packages

setup(
    name="testumbrella",
    version="1.0.3",
    packages=find_packages(),
    install_requires=[
        "clight",
        "testufirst==1.0.2",
        "testusecond==1.0.1",
        "testuthird==1.0.1",
        "testufirst"
    ],
    entry_points={
        "console_scripts": [
            "testumbrella=testumbrella.main:main",  # Entry point of the app
        ],
    },
    package_data={
        "testumbrella": [
            "main.py",
            "__init__.py",
            ".system/imports.py",
            ".system/index.py",
            ".system/modules/jobs.py",
            ".system/sources/clight.json",
            ".system/sources/logo.ico"
        ],
    },
    include_package_data=True,
    author="Irakli Gzirishvili",
    author_email="gziraklirex@gmail.com",
    description="Test umbrella project",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="",
    classifiers=[
        "Programming Language :: Python :: 3",
        
        "Operating System :: OS Independent",
    ],
)
